unit frmAdminToolU;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ComCtrls, IBServices, StdCtrls, ActnList, Menus;

type
  TfrmAdminTool = class(TForm)
    PageControl1: TPageControl;
    tabUsers: TTabSheet;
    IBSecurityService1: TIBSecurityService;
    ListView1: TListView;
    btnAdd: TButton;
    btnEdit: TButton;
    btnDelete: TButton;
    ActionList1: TActionList;
    AddUser: TAction;
    EditUser: TAction;
    DeleteUser: TAction;
    MainMenu1: TMainMenu;
    Login1: TMenuItem;
    Logout1: TMenuItem;
    Login: TAction;
    Logout: TAction;
    procedure DeleteUserUpdate(Sender: TObject);
    procedure EdiUserUpdate(Sender: TObject);
    procedure EditUserExecute(Sender: TObject);
    procedure AddUserExecute(Sender: TObject);
    procedure DeleteUserExecute(Sender: TObject);
    procedure LoginUpdate(Sender: TObject);
    procedure LogoutUpdate(Sender: TObject);
    procedure LoginExecute(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure LogoutExecute(Sender: TObject);
  private
    { Private declarations }
    FLoggedIn : Boolean;
    procedure UpdateListView;
  public
    { Public declarations }
  end;

var
  frmAdminTool: TfrmAdminTool;

implementation

uses frmUserInformationU, frmLoginU;

{$R *.DFM}

procedure TfrmAdminTool.DeleteUserUpdate(Sender: TObject);
begin
  if not FLoggedIn then
    TAction(Sender).Enabled := false
  else
    if not Assigned(ListView1.Selected) then
      TAction(Sender).Enabled := false
    else
      TAction(Sender).Enabled := not (ListView1.Selected.Caption = 'SYSDBA');
end;

procedure TfrmAdminTool.EdiUserUpdate(Sender: TObject);
begin
  TAction(Sender).Enabled := Assigned(ListView1.Selected) and FLoggedIn;
end;

procedure TfrmAdminTool.EditUserExecute(Sender: TObject);
begin
  frmUserInformation.DisplayUser(ListView1.Selected.Caption);
  if frmUserInformation.ShowModal = IDOK then
    UpdateListView;
end;

procedure TfrmAdminTool.UpdateListView;
var
  I : Integer;
begin
  with IBSecurityService1 do
  begin
    try
      IBSecurityService1.Active := true;
      DisplayUsers;
      ListView1.Items.BeginUpdate;
      ListView1.Items.Clear;
      for I := 0 to UserInfoCount - 1 do
      begin
        with UserInfo[i] do
        begin
          with ListView1.Items.Add do
          begin
            Caption := UserName;
            SubItems.Add(FirstName + ' ' + MiddleName + ' ' + LastName);
            SubItems.Add(IntToStr(UserId));
            SubItems.Add(IntToStr(GroupId));
          end;
        end;
      end;
    finally
      ListView1.Items.EndUpdate;
      IBSecurityService1.Active := false;
    end;
  end;
end;

procedure TfrmAdminTool.AddUserExecute(Sender: TObject);
begin
  frmUserInformation.DisplayUser('');
  if frmUserInformation.ShowModal = IDOK then
    UpdateListView;
end;

procedure TfrmAdminTool.DeleteUserExecute(Sender: TObject);
begin
  if MessageDlg('Are you certain you wish to delete this user?', mtConfirmation, [mbYes, mbNo], 0) = IDNO then
    Exit;
  IBSecurityService1.Active := true;
  IBSecurityService1.UserName := ListView1.Selected.Caption;
  IBSecurityService1.DeleteUser;
  IBSecurityService1.Active := false;
  UpdateListView;
end;

procedure TfrmAdminTool.LoginUpdate(Sender: TObject);
begin
  TAction(Sender).Enabled := not FLoggedIn;
end;

procedure TfrmAdminTool.LogoutUpdate(Sender: TObject);
begin
  TAction(Sender).Enabled := FLoggedIn;
end;

procedure TfrmAdminTool.LoginExecute(Sender: TObject);
begin
  with TfrmLogin.Create(self) do
  try
    if ShowModal = mrOk then
    begin
     with IBSecurityService1 do
      begin
        ServerName := edtServer.Text;
        LoginPrompt := False;
        Params.Clear;
        Params.Values['user_name'] := edtUserName.Text;
        Params.Values['password'] := edtPassword.Text;
        FLoggedIn := true;
        UpdateListView;
      end;
    end;
  finally
    Free;
  end;
end;

procedure TfrmAdminTool.FormCreate(Sender: TObject);
begin
  tabUsers.Visible := true;
  FLoggedIn := false;
end;

procedure TfrmAdminTool.LogoutExecute(Sender: TObject);
begin
  FLoggedIn := false;
  ListView1.Items.Clear;
end;

end.
